Croxy OpenAPI
Scrollen Sie nach unten, um Codebeispiele, Anfragebeispiele und Antwortbeispiele anzuzeigen.
Nach dem Anmelden finden Sie Ihren app_key auf der Startseite Ihres persönlichen Centers.
Bewahren Sie diesen Schlüssel sicher auf. Er gewährt Administratorzugriff auf Ihr Konto.
Authentifizierung
App Key
Senden Sie app_key in den POST-Parametern:
app_key: {your_app_key}
Oder senden Sie ihn als Abfrageparameter:
?app_key={your_app_key}
Antwortformat
Alle Endpunkte geben eine einheitliche JSON-Struktur zurück:
{
"code": 200,
"message": "Vorgang erfolgreich",
"data": {}
}
code: Statuscode.200bedeutet Erfolg, jeder andere Wert bedeutet, dass die Anfrage fehlgeschlagen ist.message: Antwortnachricht.data: Antwortdaten.
Basis-URLs:
Authentifizierung
- HTTP-Authentifizierung, Schema: bearer
- API Key (
apiKeyAuth)- Parametername: app_key, in
query. Unterstützt GET- und POST-Anfragen.
- Parametername: app_key, in
Proxy-Kontoverwaltung
Liste der Proxy-Konten
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/whitelist-account/list?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/whitelist-account/list
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Authentifizierungsschlüssel |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"id": 0,
"username": "string",
"password": "string",
"created_at": "string",
"remark": "string",
"product_type": 9,
"usage_flow": 0,
"limit_flow": 102400,
"status": 0
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | responseCode | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» id | integer | false | none | Kontonummer |
| »»» username | string | false | none | Name des Agentenkontos |
| »»» password | string | false | none | Passwort des Agentenkontos |
| »»» created_at | string | false | none | Fügen Sie Zeit hinzu |
| »»» remark | string | false | none | Bemerkung |
| »»» product_type | productTypes | false | none | Pakettyp: 9 dynamisches Privatverkehrspaket, 11 dynamische Privat-IP, 14 statische Rechenzentrums-IP, 25 statische Privat-IP |
| »»» usage_flow | integer | false | none | Verwendeter Traffic, Einheit: KB |
| »»» limit_flow | integer | false | none | Benutzerdefiniertes Datenverkehrslimit: Die maximale GB-Einheit beträgt 102400, 0 ist kein Limit |
| »»» status | integer | false | none | Aktivierter Status: 1 aktiviert, 0 deaktiviert |
Enumerated Values
| Property | Value |
|---|---|
| product_type | 9 |
| product_type | 11 |
| product_type | 14 |
| product_type | 25 |
Proxy-Konto hinzufügen
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/add \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/add
Body parameter
{
"app_key": "stringstringstringstringstringst",
"accounts": "user01:pass,user02:pass,user03:pass",
"remark": "",
"product_type": 9
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » accounts | body | string | false | Kontopasswort, bitte geben Sie es im Format Benutzername:Passwort ein. Konto und Passwort unterstützen nur Zahlen und Buchstaben. Die Eingabe von Sonderzeichen oder Leerzeichen ist untersagt. Ein Doppelpunkt trennt das Konto und das Passwort. Das Hinzufügen von Stapeln wird unterstützt und Agentenkonten werden durch englische Kommas (,) getrennt. |
| » remark | body | string | false | Beschreibung des Agentenkontos |
| » product_type | body | productTypes | false | Pakettyp: 9 dynamisches Privatverkehrspaket, 11 dynamische Privat-IP, 14 statische Rechenzentrums-IP, 25 statische Privat-IP |
Enumerated Values
| Parameter | Value |
|---|---|
| » product_type | 9 |
| » product_type | 11 |
| » product_type | 14 |
| » product_type | 25 |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
Proxy-Konto löschen
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/delete \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/delete
Bitte beachten Sie, dass eine Wiederherstellung nach dem Löschen nicht möglich ist und der genutzte Traffic nicht abgefragt werden kann. Für die Löschung kommt es zu einer Wartezeit von ca. 5 Minuten, in der dennoch Gebühren anfallen können.
Body parameter
{
"app_key": "stringstringstringstringstringst",
"accounts": "user01,user02"
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » accounts | body | string | false | Agentenkonto, es werden nur Zahlen und Buchstaben unterstützt. Unterstützt Batch-Vorgänge, englische Kommas (,) trennen Agentenkonten |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
Proxy-Konto deaktivieren
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/disable \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/disable
Für die Sperrung kommt es zu einer Wartezeit von ca. 5 Minuten, in der dennoch Gebühren anfallen können.
Body parameter
{
"app_key": "stringstringstringstringstringst",
"accounts": "user01,user02"
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » accounts | body | string | false | Agentenkonto, es werden nur Zahlen und Buchstaben unterstützt. Unterstützt Batch-Vorgänge, englische Kommas (,) trennen Agentenkonten |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
Proxy-Konto aktivieren
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/enable \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/enable
Body parameter
{
"app_key": "stringstringstringstringstringst",
"accounts": "user01,user02"
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » accounts | body | string | false | Agentenkonto, es werden nur Zahlen und Buchstaben unterstützt. Unterstützt Batch-Vorgänge, englische Kommas (,) trennen Agentenkonten |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
Passwort des Proxy-Kontos ändern
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/change-password \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/change-password
Bitte beachten Sie, dass nach der Änderung eine Wartezeit von 5 Minuten besteht, in der das alte Passwort weiterhin normal verwendet werden kann.
Body parameter
{
"app_key": "stringstringstringstringstringst",
"account": "user",
"password": "pass"
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » account | body | string | false | Agentenkonto, es werden nur Zahlen und Buchstaben unterstützt. |
| » password | body | string | false | Das neue Passwort für das Agentenkonto unterstützt nur Zahlen und Buchstaben. |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
Hinweis zum Proxy-Konto aktualisieren
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/change-remark \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/change-remark
Body parameter
{
"app_key": "stringstringstringstringstringst",
"account": "user",
"remark": ""
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » account | body | string | false | Agentenkonto, es werden nur Zahlen und Buchstaben unterstützt. |
| » remark | body | string | false | Neue Anmerkungen für Agenturkonten, innerhalb von 32 chinesischen Schriftzeichen oder 64 englischen Schriftzeichen. |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
Ändern Sie das Traffic-Limit des Proxy-Kontos
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/change-limit \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/change-limit
Bitte beachten Sie, dass sich die Verkehrsstatistik um bis zu 5 Minuten verzögern kann, d. h. der tatsächlich verbrauchte Verkehr kann diesen Grenzwert überschreiten.
Body parameter
{
"app_key": "stringstringstringstringstringst",
"account": "user",
"limit": 0
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » account | body | string | false | Agentenkonto, es werden nur Zahlen und Buchstaben unterstützt. |
| » limit | body | integer | false | Verkehrslimit, Einheit: GB, 0 bedeutet keine Obergrenze |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
Informationen des Proxy-Kontos aktualisieren
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/proxy-account/change \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/proxy-account/change
Ändern Sie das Passwort des Proxy-Kontos, die Bemerkungen, das Verkehrslimit, das tägliche Verkehrslimit, den Aktivierungsstatus oder den UDP-Schalter.
Body parameter
{
"app_key": "string",
"account": "string",
"password": "string",
"remark": "string",
"limit": 0,
"daily_limit": 0,
"status": 0,
"udp": 0
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » account | body | string | false | Name des Agentenkontos |
| » password | body | string | false | Neues Passwort, 6-16 Ziffern oder Buchstaben; Wenn es nicht übergeben wird, wird es nicht geändert. |
| » remark | body | string | false | Neuer Hinweis |
| » limit | body | integer | false | Verkehrslimit, Einheit GB, 0 bedeutet kein Limit |
| » daily_limit | body | integer | false | Tägliches Traffic-Limit in GB, 0 bedeutet kein Limit |
| » status | body | integer | false | Aktivierter Status |
| » udp | body | integer | false | UDP-Unterstützungsschalter, nur wirksam für Pakettypen 14, 16, 21 und 25 |
Enumerated Values
| Parameter | Value |
|---|---|
| » status | 0 |
| » status | 1 |
| » udp | 0 |
| » udp | 1 |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 Erfolg |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
Auftragsverwaltung
Aufträge erstellen, abfragen und stornieren.
Bestellliste
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/order/list \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/order/list
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| page_no | query | integer | false | none |
| page_size | query | integer | false | none |
| trade_no | query | string | false | Bestellnummer |
| start_time | query | string(date-time) | false | Startzeit (einschließlich), z. B. 01.01.2024 00:00:00 |
| end_time | query | string(date-time) | false | Endzeit (nicht inbegriffen) |
| status | query | integer | false | Bestellstatus |
| product_type | query | integer | false | Produkttyp |
| invoice | query | integer | false | Rechnungsstatus: 0 keine Begrenzung 1 in Rechnung gestellt -1 nicht in Rechnung gestellt (kann erneut ausgestellt werden) |
| pay_fee_status | query | integer | false | Prüfung auf lange und kurze Zahlungen: 1 Überzahlung, 2 Unterzahlung |
Detailed descriptions
status: Bestellstatus
| Status | Beschreibung |
|---|---|
| 0 | Ausstehende Zahlung |
| 1 | Bezahlt |
| 2 | Abgesagt wegen Überstunden und Nichtzahlung |
| 3 | Erstattet |
product_type: Produkttyp | Produkttyp | Beschreibung | |---|---| |3|Guthabenaufladung| |9|Dynamisches Verkehrspaket| |11|Dynamic Global Time Package V2| |12|Langfristiges IDC-Verkehrspaket| |13|Statisches IP-Verkehrspaket für Privathaushalte| |14|Statisches IP-Paket des Rechenzentrums| |15|Langfristiges ISP-Traffic-Paket| |16|Statisches Verkehrspaket| |17|Dynamisches IP-Mengenpaket| |18|Web-Scraper| |19|Statische IP-Erneuerung| |20|Statisches IP-Ersatzkontingent| |21|Statisches Verkehrspaket v2| |24|Zusatzpaket für statischen Datenverkehr| |25|Statisches IP-Paket für Privathaushalte| |26|Ersatzbestellung – Bei einigen Zahlungskanälen müssen Benutzer den Betrag manuell eingeben, z. B. bei virtueller Währung. Wenn es zu einer Minderzahlung kommt, müssen Sie sich an den Kundendienst wenden, um eine Rückzahlung über dieses Produkt vorzunehmen| |27|Serp| |28|Video|
Enumerated Values
| Parameter | Value |
|---|---|
| status | 0 |
| status | 1 |
| status | 2 |
| status | 3 |
| product_type | 3 |
| product_type | 9 |
| product_type | 11 |
| product_type | 12 |
| product_type | 14 |
| product_type | 16 |
| product_type | 17 |
| product_type | 18 |
| product_type | 19 |
| product_type | 21 |
| product_type | 24 |
| product_type | 25 |
| product_type | 26 |
| product_type | 27 |
| product_type | 28 |
| invoice | -1 |
| invoice | 0 |
| invoice | 1 |
| pay_fee_status | 1 |
| pay_fee_status | 2 |
Antwortbeispiele
200 Response
{
"code": 0,
"message": "Operation erfolgreich",
"data": {
"list": [
{
"id": 0,
"trade_no": "string",
"out_trade_no": "string",
"product_id": 0,
"product_type": 0,
"amount": 0,
"unit_price": 0.1,
"total_fee": 0.1,
"goods_fee": 0.1,
"pay_fee": 0.1,
"discount_fee": 0.1,
"handling_fee": 0.1,
"refund_fee": 0.1,
"pm_id": 0,
"pm_title": "string",
"pm_logo": "string",
"status": 0,
"title": "string",
"detail": "string",
"region_desc": "string",
"pay_at": "2019-08-24T14:15:22Z",
"pay_timestamp": 0,
"created_at": "2019-08-24T14:15:22Z",
"pay_fee_status": 0,
"invoice": {
"name": "string",
"org_name": "string",
"first_name": "string",
"last_name": "string",
"phone": "string",
"email": "[email protected]",
"role_type": 0,
"vat_id": "string",
"address_country": "string",
"address_city": "string",
"address_line1": "string",
"address_line2": "string",
"address_postal_code": "string"
}
}
],
"pagination": {
"total": 0,
"page_no": 0,
"page_size": 0,
"total_pages": 0
}
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Erfolg | Inline |
Antwortschema
Ordnung schaffen
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/order/create \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/order/create
Da es viele Arten von Paketen gibt und jedes Paket unterschiedliche Konfigurationen hat, füllen Sie bitte die Parameter entsprechend der tatsächlichen Situation aus. Eine unsachgemäße Eingabe von Parametern kann dazu führen, dass die Auftragserstellung fehlschlägt.
Beispiele:
Statische IP erneuern
„json { „pid“: Paket-ID, // erhalten von der /open/product-Schnittstelle „upids“: „1,2,3,4,5,6“, // Holen Sie sich das entsprechende ID-Feld von der /open/ip/get-static-ip-Schnittstelle "pm_id": 1 // Von der Schnittstelle /open/ payment/list oder /open/ payment/groups bezogen } „
Statischer IP-Kauf für Privathaushalte
„json { „pid“: Paket-ID, // erhalten von der /open/product-Schnittstelle „pm_id“: Zahlungsmethoden-ID, // erhalten von der Schnittstelle /open/ payment/list oder /open/ payment/groups „region_list“: „JP,15,333|DE,10,444|US,5,555“ // Format: Region, Menge, ASN|Region, Menge, ASN (ASN-Nummer optional) } „
Statischer IP-Kauf für Rechenzentren
„json { „pid“: Paket-ID, // erhalten von der /open/product-Schnittstelle „pm_id“: Zahlungsmethoden-ID, // erhalten von der Schnittstelle /open/ payment/list oder /open/ payment/groups „region_list“: „JP,15,333|DE,10,444|US,5,555“ // Format: Region, Menge, ASN|Region, Menge, ASN (ASN-Nummer optional) } „
Dynamischer Kauf im Wohngebiet
„json { „pid“: Paket-ID, // erhalten von der /open/product-Schnittstelle „pm_id“: Zahlungsmethoden-ID // Von der Schnittstelle /open/paid/list oder /open/paid/groups erhalten } „
Kauf von statischem Rotationsverkehr
„json { „pid“: Paket-ID, // erhalten von der /open/product-Schnittstelle „pm_id“: Zahlungsmethoden-ID // Von der Schnittstelle /open/paid/list oder /open/paid/groups erhalten } „
Dynamischer unbegrenzter Traffic-Kauf
„json { „pid“: Paket-ID, // erhalten von der /open/product-Schnittstelle „pm_id“: Zahlungsmethoden-ID, // erhalten von der Schnittstelle /open/ payment/list oder /open/ payment/groups „product_sku_bandwidth_id“: Bandbreitenspezifikations-ID, „product_sku_concurrency_id“: Parallelitätsspezifikations-ID } „
Guthaben aufladen
„json { „pid“: Paket-ID, // erhalten von der /open/product-Schnittstelle „pm_id“: Zahlungsmethoden-ID, // erhalten von der Schnittstelle /open/ payment/list oder /open/ payment/groups „recharge_amount“: Aufladebetrag } „
Body parameter
{
"pid": 0,
"upids": "string",
"amount": 0,
"pm_id": 0,
"region_list": "string",
"coupon_sn": "string",
"use_invitation_registration_discount": true,
"renew_duration": 0,
"product_sku_bandwidth_id": 0,
"product_sku_concurrency_id": 0,
"product_sku_duration_id": 0,
"etd": 1,
"recharge_amount": 0
}
Parameter
| Name | In | Type | Required | Description | | --- | --- | --- | --- | --- | --- | --- | --- | | body | body | object | true | none | | » pid | body | integer | true | Paket-ID aus dem ID-Feld, das von der /open/product-Schnittstelle zurückgegeben wird | | » upids | body | string | false | Liste der Verlängerungspaket-IDs (durch Kommas getrennt) aus dem ID-Feld, das von der Schnittstelle /open/user-product/list oder /open/ip/get-static-ip zurückgegeben wird | | » amount | body | number | false | Anzahl der neu gekauften Pakete | | » pm_id | body | integer | true | Zahlungsmethoden-ID aus dem ID-Feld, das von der Schnittstelle /open/ payment/list oder /open/ payment/groups zurückgegeben wird | | » region_list | body | string | false | Geben Sie beim Kauf einer statischen IP die Region + Menge + ASN-Nummer an. Das Format ist: Region, Menge, ASN | Region, Menge, ASN. Beispiel: JP,15,333 | DE,10,444 | US,5,555 (ASN-Nummer ist optional) | | » coupon_sn | body | string | false | Gutscheinnummer | | » use_invitation_registration_discount | body | boolean | false | Ob der Rabatt für die Einladungsregistrierung genutzt werden soll | | » renew_duration | body | integer | false | Erneuerungszeit der statischen IP optional | | » product_sku_bandwidth_id | body | integer | false | Paket 11: Bandbreiten-Paket-ID | | » product_sku_concurrency_id | body | integer | false | Paket 11: Gleichzeitige Paket-ID | | » product_sku_duration_id | body | integer | false | Pakettyp=11Erforderlich: Dauerspezifikations-ID | | » etd | body | integer | false | Dauermultiplikator, erhalten aus dem Paket extension_of_time_days, 2 stellt die Anzahl der Tage × 2 dar, der Preis erhöht sich | | » recharge_amount | body | integer | false | Paket 3: Aufladebetrag |
Antwortbeispiele
200 Response
{
"code": 0,
"message": "Operation erfolgreich",
"data": {
"id": 0,
"trade_no": "string",
"out_trade_no": "string",
"product_id": 0,
"product_type": 0,
"amount": 0,
"unit_price": 0.1,
"total_fee": 0.1,
"goods_fee": 0.1,
"pay_fee": 0.1,
"discount_fee": 0.1,
"handling_fee": 0.1,
"refund_fee": 0.1,
"pm_id": 0,
"pm_title": "string",
"pm_logo": "string",
"status": 0,
"title": "string",
"detail": "string",
"region_desc": "string",
"pay_at": "2019-08-24T14:15:22Z",
"pay_timestamp": 0,
"created_at": "2019-08-24T14:15:22Z",
"pay_fee_status": 0,
"invoice": {
"name": "string",
"org_name": "string",
"first_name": "string",
"last_name": "string",
"phone": "string",
"email": "[email protected]",
"role_type": 0,
"vat_id": "string",
"address_country": "string",
"address_city": "string",
"address_line1": "string",
"address_line2": "string",
"address_postal_code": "string"
}
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Erfolgreich erstellt | Inline |
Antwortschema
Bestellung stornieren
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/order/close \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/order/close
Body parameter
{
"trade_no": "string"
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | true | none |
| » trade_no | body | string | true | none |
Antwortbeispiele
200 Response
{
"code": 0,
"message": "Operation erfolgreich",
"data": {}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Operation erfolgreich | SuccessResponse |
Vorabcheck bestellen
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/order/check \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/order/check
Wird vor dem Erstellen einer Bestellung aufgerufen und dient der Vorschau von Preisen, Rabatten, IP-Erneuerungsdetails usw. Die Bestellung wird nicht tatsächlich erstellt. Die Parameter sind genau die gleichen wie „/open/order/create“.
Body parameter
{
"pid": 0,
"upids": "string",
"amount": 1,
"pm_id": 0,
"region_list": "string",
"coupon_sn": "string",
"renew_duration": "1m",
"product_sku_bandwidth_id": 0,
"product_sku_concurrency_id": 0,
"product_sku_duration_id": 0,
"etd": 1,
"recharge_amount": 0
}
Parameter
| Name | In | Type | Required | Description | | ---------------------------- | ---- | ------- | -------- | ------------------------------------------------------------------------ | ----------------- | | body | body | object | true | none | | » pid | body | integer | true | Paket-ID | | » upids | body | string | false | IP-Erneuerung: Liste der Benutzerpaket-IDs, durch Kommas getrennt | | » amount | body | integer | false | Kaufmenge | | » pm_id | body | integer | true | Zahlungsmethoden-ID | | » region_list | body | string | false | Statische IP-Kaufregion + Menge, Format: Regions-ID, Menge | Regions-ID, Menge | | » coupon_sn | body | string | false | Gutscheinnummer | | » renew_duration | body | string | false | IP-Erneuerungszeitraum: 1m=1 Monat, 2m=2 Monate, em=Ende nächsten Monats | | » product_sku_bandwidth_id | body | integer | false | Pakettyp=11Erforderlich: Bandbreitenspezifikations-ID | | » product_sku_concurrency_id | body | integer | false | Pakettyp=11Erforderlich: Parallelitätsspezifikations-ID | | » product_sku_duration_id | body | integer | false | Pakettyp=11Erforderlich: Dauerspezifikations-ID | | » etd | body | integer | false | Dauermultiplikator, erhalten aus dem Paket extension_of_time_days | | » recharge_amount | body | number | false | Pakettyp=3Erforderlich: Aufladebetrag |
Enumerated Values
| Parameter | Value |
|---|---|
| » renew_duration | 1m |
| » renew_duration | 2m |
| » renew_duration | em |
Antwortbeispiele
200 Response
{
"code": 0,
"message": "Operation erfolgreich",
"data": {
"product_id": 0,
"amount": 0,
"discount_fee": 0.1,
"total_fee": 0.1,
"pay_fee": 0.1,
"product_type": 0,
"title": "string",
"detail": "string",
"ip_result": [
{
"ip": "string",
"price": 0.1,
"country_code": "string",
"current_time": "2019-08-24T14:15:22Z",
"renewal_time": "2019-08-24T14:15:22Z",
"country": {
"name_zh_cn": "string",
"flag": "string",
"square_flag": "string"
}
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Preflight erfolgreich | Inline |
Antwortschema
IP-Whitelist
IP-Whitelist-Liste
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/proxy-ip/list?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/proxy-ip/list
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Authentifizierungsschlüssel |
| product_type | query | integer | false | Nummer des Pakettyps |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"ip": "1.1.1.1",
"remark": "string",
"product_type": 0,
"created_at": "string"
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 Erfolg |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» ip | string | false | none | IP auf die Whitelist setzen |
| »»» remark | string | false | none | Bemerkung |
| »»» product_type | integer | false | none | Pakettyp |
| »»» created_at | string | false | none | Schöpfungszeit |
IP-Whitelist hinzufügen
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/proxy-ip/add \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/proxy-ip/add
Body parameter
{
"app_key": "string",
"ips": "1.1.1.1,2.2.2.2",
"remark": "string",
"product_type": 0,
"user_product_id": 0
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » ips | body | string | false | IPs, die hinzugefügt werden müssen, auf die Whitelist setzen, mehrere durch Kommas oder Zeilenumbrüche trennen. |
| » remark | body | string | false | Bemerkung |
| » product_type | body | integer | false | Nummer des Pakettyps |
| » user_product_id | body | integer | false | Benutzerpaket-ID, erforderlich, wenn der Pakettyp 11 ist |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 Erfolg |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
IP-Whitelist löschen
Codebeispiele
# You can also use wget
curl -X POST https://api.croxy.com/open/proxy-ip/delete \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/proxy-ip/delete
Body parameter
{
"app_key": "string",
"ips": "1.1.1.1,2.2.2.2",
"verify_type": "string",
"verify_code": "string"
}
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Autorisierungsschlüssel |
| » ips | body | string | false | Whitelist-IPs, die gelöscht werden müssen, mehrere durch Kommas getrennt |
| » verify_type | body | string | false | Verifizierungstyp: Telefon, E-Mail, WeChat, ToTP |
| » verify_code | body | string | false | Bestätigungscode |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 Erfolg |
| » msg | string | false | none | Statusmeldung |
| » data | null | false | none | none |
Traffic-Logs
Die Verkehrsnutzung wird nach Tag zusammengefasst
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/user-usage-flow/total?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/user-usage-flow/total
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Authentifizierungsschlüssel |
| start_time | query | string(Y-m-d H:i:s) | false | Startzeit, sekundengenau. Bitte beachten Sie, dass sich die Protokollierung um 5 Minuten verzögert. Die Verzugsfrist beträgt 7 Tage. |
| end_time | query | string(Y-m-d H:i:s) | false | Frist, sekundengenau. Bitte beachten Sie, dass sich die Protokollierung um 5 Minuten verzögert. Aktuelle Standardzeit. |
| username | query | string | false | Unterkontoname, standardmäßig alle Konten abfragen, Unterkonto kann angegeben werden. Bitte beachten Sie, dass diese Abfrage alle Nutzungsdatensätze für das Agentenkonto mit demselben Namen zurückgibt, wenn Sie ein Unterkonto mit demselben Namen hinzufügen. |
| product_type | query | number | false | Pakettyp |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"day": "2022-08-01",
"flow": 0
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» day | string | false | none | Datum |
| »»» flow | integer | false | none | Verbrauchsverkehr, Einheit KB |
Paketabfrage
Liste der gekauften Pakete
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/user-product/list?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/user-product/list
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Authentifizierungsschlüssel |
| trade_no | query | string | false | Bestellnummer, bitte geben Sie die vollständige Bestellnummer ein. Die Fuzzy-Suche wird nicht unterstützt. |
| page | query | number | false | Paginierung, Standard: 1 |
| size | query | number | false | Anzahl der angezeigten Seiten, Standard: 20 |
| product_type | query | number | false | Pakettyp |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"id": 0,
"created_at": "2022-05-13 12:14:15",
"expired_at": "2022-05-13 12:14:15",
"product_type": 9,
"trade_no": "2022051312134339861461465434",
"order": {
"created_at": "2022-05-13 12:13:43",
"pay_at": "2022-05-13 12:13:43",
"title": "Einstiegsniveau"
}
}
],
"page": 1,
"page_size": 20,
"total_count": 0,
"total_page": 0
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» id | integer | false | none | Paketnummer |
| »»» created_at | string | false | none | Paketwirksame Zeit |
| »»» expired_at | string | false | none | Die Ablaufzeit des Pakets. Nach Ablauf kann der Traffic nicht mehr genutzt werden. |
| »»» product_type | productTypes | false | none | Pakettyp: 9 dynamisches Privatverkehrspaket, 11 dynamische Privat-IP, 14 statische Rechenzentrums-IP, 25 statische Privat-IP |
| »»» trade_no | string | false | none | Transaktionsnummer der Bestellung |
| »»» order | object | false | none | none |
| »»»» created_at | string | false | none | Zeitpunkt der Auftragserstellung |
| »»»» pay_at | string | false | none | Zahlungszeitpunkt der Bestellung |
| »»»» title | string | false | none | Bestellbeschreibung |
| »» page | integer | false | none | Aktuelle Seite |
| »» page_size | integer | false | none | Seitengröße |
| »» total_count | integer | false | none | Gesamtzahl der Datensätze |
| »» total_page | integer | false | none | Gesamtzahl der Seiten |
Enumerated Values
| Property | Value |
|---|---|
| product_type | 9 |
| product_type | 11 |
| product_type | 14 |
| product_type | 25 |
Zusammenfassung der Benutzerpaketdaten
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/user-product/summary?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/user-product/summary
Erhalten Sie statistische Übersichtsinformationen zu Benutzerpaketen, einschließlich Gesamtbetrag, effektiver Betrag, bevorstehender Betrag, abgelaufener Betrag usw.
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Authentifizierungsschlüssel |
| product_type | query | integer | false | Produkttyp, unterstützt nur 9 (dynamisches Verkehrspaket), 12 (langfristiges IDC-Verkehrspaket) |
Enumerated Values
| Parameter | Value |
|---|---|
| product_type | 9 |
| product_type | 12 |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "Erfolg",
"data": {
"total": 1048576,
"total_count": 5,
"effective": 524288,
"effective_count": 3,
"effective_total": 786432,
"effective_used": 262144,
"temporary": 102400,
"temporary_count": 1,
"expired": 51200,
"expired_count": 1,
"used": 473088
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» total | integer | false | none | Traffic/Gesamt-IP-Volumen (Einheit: KB) |
| »» total_count | integer | false | none | Gesamtzahl der Pakete |
| »» effective | integer | false | none | Effektiver Restbetrag (Einheit: KB) |
| »» effective_count | integer | false | none | Anzahl gültiger Pakete |
| »» effective_total | integer | false | none | Effektiver Gesamtbetrag (Einheit: KB) |
| »» effective_used | integer | false | none | Effektiv genutzter Betrag (Einheit: KB) |
| »» temporary | integer | false | none | Gesamtbetrag fällig (fällig innerhalb von 7 Tagen, Einheit: KB) |
| »» temporary_count | integer | false | none | Anzahl ablaufender Pakete (Ablauf innerhalb von 7 Tagen) |
| »» expired | integer | false | none | Abgelaufener Restbetrag (Einheit: KB) |
| »» expired_count | integer | false | none | Anzahl abgelaufener Pakete |
| »» used | integer | false | none | Gesamtverbrauch (Einheit: KB) |
IP-Abruf
IP extrahieren
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/v3?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/v3
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Zugangsschlüssel |
| cc | query | string | false | Land oder Region |
| state | query | string | false | Provinz oder Staat |
| city | query | string | false | Stadt |
| format | query | string | false | Format abrufen |
| lb | query | string | false | Trennzeichen, nur im Textformat gültig |
| num | query | number | false | Menge extrahieren |
| life | query | number | false | Haltedauer – Minuten |
| ep | query | string | false | Proxy-Netzwerk |
Enumerated Values
| Parameter | Value |
|---|---|
| ep | us |
| ep | hk |
| ep | de |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
[
"150.109.114.72:1140",
"150.109.114.72:1141",
"150.109.114.72:1142",
"150.109.114.72:1143",
"150.109.114.72:1144",
"150.109.114.72:1145",
"150.109.114.72:1146",
"150.109.114.72:1147",
"150.109.114.72:1148",
"150.109.114.72:1149"
]
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [any] | false | none | none |
Dynamische regionale Städteliste V4
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dcl4?username=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dcl4
Rufen Sie die Städteliste nach Benutzernamen ab, eine Anmeldeauthentifizierung ist erforderlich und das Konto muss dem aktuellen Benutzer gehören
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| username | query | string | true | Benutzername des Agentenkontos |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"cache": true,
"list": [
{
"City": "Los Angeles",
"Area": "US",
"State": "California"
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 Erfolg |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» cache | boolean | false | none | Ob es aus dem Cache kommt |
| »» list | [object] | false | none | none |
| »»» City | string | false | none | Stadt |
| »»» Area | string | false | none | Bereich |
| »»» State | string | false | none | Staat/Provinz |
Dynamische regionale Bundesland-/Provinzliste V4
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dsl4?username=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dsl4
Rufen Sie die Bundesland-/Provinzliste nach Benutzernamen ab, eine Anmeldeauthentifizierung ist erforderlich und das Konto muss dem aktuellen Benutzer gehören
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| username | query | string | true | Benutzername des Agentenkontos |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"cache": true,
"list": [
{
"City": "Los Angeles",
"Area": "US",
"State": "California"
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 Erfolg |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» cache | boolean | false | none | Ob es aus dem Cache kommt |
| »» list | [object] | false | none | none |
| »»» City | string | false | none | Stadt |
| »»» Area | string | false | none | Bereich |
| »»» State | string | false | none | Staat/Provinz |
Dynamische regionale Landes-/Provinzstadt-Fusionsliste V4
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dal4?username=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dal4
Erhalten Sie eine zusammengeführte Liste von Bundesstaaten/Provinzen und Städten nach Benutzernamen, gruppiert nach Region. Eine Anmeldeauthentifizierung ist erforderlich und das Konto muss dem aktuellen Benutzer gehören
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| username | query | string | true | Benutzername des Agentenkontos |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"cache": true,
"list": [
{
"Area": "US",
"states": [
{
"State": "California",
"cities": ["Los Angeles"]
}
]
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 Erfolg |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» cache | boolean | false | none | Ob es aus dem Cache kommt |
| »» list | [object] | false | none | Bereichsliste |
| »»» Area | string | false | none | Vorwahl |
| »»» states | [object] | false | none | Liste der Bundesstaaten/Provinzen |
| »»»» State | string | false | none | Name des Bundesstaats/der Provinz |
| »»»» cities | [string] | false | none | Städteliste |
Städteliste
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dynamic-citys \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dynamic-citys
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"name_zh_cn": "USA",
"name_en": "United States",
"continent_code": "NA",
"country_code": "US",
"items": [
{
"city": "Arlington",
"state": "alabama",
"continent_code": "NA",
"country_code": "US"
}
]
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [object] | false | none | Liste |
| »»» name_zh_cn | string | false | none | Name des Landes oder der Region |
| »»» name_en | string | false | none | Name des Landes oder der Region |
| »»» continent_code | string | false | none | Kontinentcode |
| »»» country_code | string | false | none | Länder- oder Regionscode |
| »»» items | [any] | false | none | Provinz oder Staat |
| »»»» city | string | false | none | Stadtname |
| »»»» state | string | false | none | Provinz- oder Staatsnamencode |
| »»»» continent_code | string | false | none | Kontinentcode |
| »»»» country_code | string | false | none | Länder- oder Regionscode |
Stadtsuche
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dynamic-citys/search?country_code=string&state=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dynamic-citys/search
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| country_code | query | string | true | Länder- oder Regionscode |
| state | query | string | true | Staats- oder Provinzcode |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": ["string"]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [string] | false | none | Liste |
Staatsliste
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dynamic-states \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dynamic-states
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"name_zh_cn": "USA",
"name_en": "United States",
"continent_code": "NA",
"country_code": "US",
"items": [
{
"state": "alabama",
"continent_code": "NA",
"country_code": "US"
}
]
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [object] | false | none | Liste |
| »»» name_zh_cn | string | false | none | Name des Landes oder der Region |
| »»» name_en | string | false | none | Name des Landes oder der Region |
| »»» continent_code | string | false | none | Kontinentcode |
| »»» country_code | string | false | none | Länder- oder Regionscode |
| »»» items | [any] | false | none | Provinz oder Staat |
| »»»» state | string | false | none | Provinz- oder Staatsnamencode |
| »»»» continent_code | string | false | none | Kontinentcode |
| »»»» country_code | string | false | none | Länder- oder Regionscode |
Suche nach Bundesstaat/Provinz
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dynamic-states/search?country_code=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dynamic-states/search
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| country_code | query | string | true | Länder- oder Regionscode |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": ["string"]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig, 156 Konto nicht authentifiziert. |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [string] | false | none | Liste |
Extrahieren Sie die gekaufte statische IP-Liste
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/get-static-ip \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/get-static-ip
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| country_code | query | string | false | Länder- oder Regionscode |
| product_type | query | number | false | Produkttyp, 25: Statische Privat-IP, 14: Rechenzentrums-IP |
| trade_no | query | string | false | IP nach Bestellnummer filtern |
| page | query | number | false | Seitenzahl |
| size | query | number | false | Menge pro Seite |
| status | query | number | false | Status, 1: gültig, 2: ungültig, 3: bald ablaufend, 4: in Wartung |
Enumerated Values
| Parameter | Value |
|---|---|
| product_type | 14 |
| product_type | 25 |
| status | 1 - 2 - 3 - 4 |
Antworten
| Status | Meaning | Description | Schema |
|---|
Ermitteln Sie die Anzahl der in der Region zum Verkauf stehenden statischen IPs
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/static-ip-region \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/static-ip-region
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| isp | query | integer | false | ISP-Filterung, keine Filterung, wenn nicht übertragen (Standard ist 1, außer Standort 1/4/5) |
| asn | query | integer | false | Ob ASN-Paketdaten zurückgegeben werden sollen |
| exclusive | query | integer | false | Ob nach exklusivem Inventar gezählt werden soll |
Detailed descriptions
isp: ISP-Filterung, keine Filterung, wenn nicht übertragen (Standard ist 1, außer Standort 1/4/5)
| Wert | Beschreibung |
|---|---|
| 0 | Statische IP des Rechenzentrums (IDC) |
| 1 | Statische Home-IP (ISP) |
asn: Ob ASN-Paketdaten zurückgegeben werden sollen
| Wert | Beschreibung |
|---|---|
| 0 | Keine ASN-Paketdaten zurückgeben (Standard) |
| 1 | ASN-Paketdaten zurückgeben |
exclusive: Ob nach exklusivem Inventar gezählt werden soll
| Wert | Beschreibung |
|---|---|
| 0 | Statistiken basierend auf dem aktuellen Benutzer-/Freigabegruppenkaliber (Standard) |
| 1 | Alle zugewiesenen IPs ausschließen und nur verfügbaren Bestand zählen |
Enumerated Values
| Parameter | Value |
|---|---|
| isp | 0 |
| isp | 1 |
| asn | 0 |
| asn | 1 |
| exclusive | 0 |
| exclusive | 1 |
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "Anfrage erfolgreich",
"data": {
"list": [
{
"code": "US",
"number": 55
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 Erfolg |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [any] | false | none | none |
| »»» code | string | false | none | Länder- oder Regionscode |
| »»» number | integer | false | none | Menge |
Erhalten Sie von host_pool unterstützte Länder/Regionen
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/host-pool/regions \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/host-pool/regions
Fragen Sie die Liste der Länder/Regionen ab, die von der aktuellen Site des host_pool-Dienstes unterstützt werden.
Diese Schnittstelle ist auf das Zufallsextraktionsszenario der Rechenzentrums-IP basierend auf Verkehrspunkten ausgerichtet und zählt nur Länder/Regionen basierend auf dem am aktuellen Standort verfügbaren Rechenzentrums-IP-Inventar. ASN, ISP und exklusive Inventarfilterung werden nicht unterstützt und IPs werden nicht durch vom Benutzer erworbene Datensätze ausgeschlossen.
Antwortbeispiele
200 Response
{
"code": 200,
"msg": "Anfrage erfolgreich",
"data": {
"list": [
{
"code": "US",
"number": 55,
"name_zh_cn": "USA",
"name_en": "United States",
"square_flag": "https://example.com/static/flags/us.png"
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Anfrage erfolgreich | Inline |
Antwortschema
Statuscode 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Statuscode, 200 Erfolg |
| » msg | string | false | none | Statusmeldung |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» code | string | false | none | Länder- oder Regionscode, ISO 3166-1 Alpha-2 |
| »»» number | integer | false | none | Anzahl der am aktuellen Standort verfügbaren Rechenzentrums-IPs |
| »»» name_zh_cn | string | false | none | Chinesischer Name des Landes oder der Region |
| »»» name_en | string | false | none | Englischer Name des Landes oder der Region |
| »»» square_flag | string | false | none | Bild-URL der quadratischen Flagge |
Zahlungsverwaltung
Erhalten Sie eine Liste der Zahlungsmethoden
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/payment/groups \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/payment/groups
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| trade_no | query | undefined | false | Bestellnummer – kann übergeben werden, wenn für einige Bestellungen eine bestimmte Zahlungsmethode erforderlich ist |
Antwortbeispiele
200 Response
{
"code": 0,
"message": "Operation erfolgreich",
"data": {
"list": [
{
"name": "string",
"logos": ["string"],
"items": [
{
"id": 0,
"title": "string",
"logo": "string",
"group": "string",
"disabled": false,
"min": 0,
"max": 0
}
]
}
]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Erfolg haben | Inline |
Antwortschema
Marketing
Aufladebonusverhältnis
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/activity/balance-recharge-gift-ratio \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/activity/balance-recharge-gift-ratio
Aufladebonusverhältnis
Antwortbeispiele
200 Response
{
"code": 0,
"message": "Operation erfolgreich",
"data": {
"list": [null]
}
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Inline |
Antwortschema
Produkte
Produktliste
Codebeispiele
# You can also use wget
curl -X GET https://api.croxy.com/open/product \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/product
Rufen Sie die Liste der auf der aktuellen Website zum Kauf verfügbaren Pakete ab und unterstützen Sie die Filterung nach Typ, Gültigkeitsdauer und anderen Bedingungen.
Parameter
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| type | query | integer | false | Pakettyp, siehe Beschreibung der Product.type-Enumeration. Wenn nicht übergeben, werden alle Typen zurückgegeben. |
| parent_product_type | query | integer | false | Übergeordneter Pakettyp, nur gültig, wenn Typ=19 (IP-Erneuerung), zum Filtern von Produktlinien verwendet: 14=Rechenzentrum 25=Wohnbereich |
| time_days | query | any | false | Filterung des Gültigkeitszeitraums, unterstützt Einzelwerte oder Arrays, z. B. 30 / [30,90,365] |
| show_type | query | any | false | Anzeigetypfilterung, unterstützt Einzelwert oder Array |
Enumerated Values
| Parameter | Value |
|---|---|
| parent_product_type | 14 |
| parent_product_type | 25 |
Antwortbeispiele
200 Response
{
"code": 0,
"message": "Operation erfolgreich",
"data": [
{
"id": 0,
"title": "string",
"type": 0,
"show_type": 0,
"status": 0,
"price": 0.1,
"usd_price": 0.1,
"price_hkd": 0.1,
"original_price": 0.1,
"original_usd_price": 0.1,
"original_price_hkd": 0.1,
"local_price": 0.1,
"local_original_price": 0.1,
"preferred_currency": "string",
"support_currencies": "string",
"flow_value": 0.1,
"flow_give": 0.1,
"balance_give": 0.1,
"balance_value": 0.1,
"time_validity": 0.1,
"time_price": 0.1,
"time_days": 0,
"tip1": "string",
"tip2": "string",
"introduce": ["string"],
"region_list_id": 0,
"renew_product_list": "string",
"parent_product_type": 0,
"total_count": 0,
"remain_count": 0,
"extension_of_time_days": [0],
"time_days_price_rate": 0.1,
"desc": {
"subtitle": "string",
"flow_value": 0.1,
"flow_give": 0.1,
"balance_give": 0.1,
"time_validity": 0.1,
"time_price": 0.1,
"tip1": "string",
"tip2": "string",
"introduce": ["string"]
},
"sku": {
"bandwidth_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
],
"duration_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
],
"concurrency_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
]
}
}
]
}
Antworten
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Inline |
Antwortschema
Schemas
productTypes
9
Pakettyp: 9 dynamisches Privatverkehrspaket, 11 dynamische Privat-IP, 14 statische Rechenzentrums-IP, 25 statische Privat-IP
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| anonymous | integer | false | none | Pakettyp: 9 dynamisches Privatverkehrspaket, 11 dynamische Privat-IP, 14 statische Rechenzentrums-IP, 25 statische Privat-IP |
Enumerated Values
| Property | Value |
|---|---|
| anonymous | 9 |
| anonymous | 11 |
| anonymous | 14 |
| anonymous | 25 |
apiKey
{}
Authentifizierungsschlüssel
Properties
None
responseCode
200
Statuscode, 200 erfolgreich, 3 app_key ungültig
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| anonymous | integer | false | none | Statuscode, 200 erfolgreich, 3 app_key ungültig |
responseMsg
"erfolgreich"
Antwortnachricht
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| anonymous | string | false | none | Antwortnachricht |
SuccessResponse
{
"code": 0,
"message": "Operation erfolgreich",
"data": {}
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| code | integer | false | none | none |
| message | string | false | none | none |
| data | object | false | none | none |
ErrorResponse
{
"code": 400,
"message": "Parameterfehler",
"errors": {}
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| code | integer | false | none | none |
| message | string | false | none | none |
| errors | object | false | none | none |
User
{
"id": 0,
"email": "[email protected]",
"phone": "string",
"balance": 0.1,
"status": 0,
"is_real_name": true,
"created_at": "2019-08-24T14:15:22Z"
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| string(email) | false | none | none | |
| phone | string | false | none | none |
| balance | number(float) | false | none | none |
| status | integer | false | none | none |
| is_real_name | boolean | false | none | none |
| created_at | string(date-time) | false | none | none |
Order
{
"id": 0,
"trade_no": "string",
"out_trade_no": "string",
"product_id": 0,
"product_type": 0,
"amount": 0,
"unit_price": 0.1,
"total_fee": 0.1,
"goods_fee": 0.1,
"pay_fee": 0.1,
"discount_fee": 0.1,
"handling_fee": 0.1,
"refund_fee": 0.1,
"pm_id": 0,
"pm_title": "string",
"pm_logo": "string",
"status": 0,
"title": "string",
"detail": "string",
"region_desc": "string",
"pay_at": "2019-08-24T14:15:22Z",
"pay_timestamp": 0,
"created_at": "2019-08-24T14:15:22Z",
"pay_fee_status": 0,
"invoice": {
"name": "string",
"org_name": "string",
"first_name": "string",
"last_name": "string",
"phone": "string",
"email": "[email protected]",
"role_type": 0,
"vat_id": "string",
"address_country": "string",
"address_city": "string",
"address_line1": "string",
"address_line2": "string",
"address_postal_code": "string"
}
}
Properties
| Name | Type | Required | Restrictions | Description | | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | | id | integer | false | none | Bestell-ID | | trade_no | string | false | none | Interne Bestellnummer | | out_trade_no | string | false | none | Externe Bestellnummer | | product_id | integer | false | none | Paket-ID | | product_type | integer | false | none | Pakettyp, siehe Produkttypaufzählung | | amount | integer | false | none | Kaufmenge | | unit_price | number(float) | false | none | Stückpreis | | total_fee | number(float) | false | none | Gesamtbestellpreis (ohne Rabatte und Bearbeitungsgebühren) | | goods_fee | number(float) | false | none | Produktpreis (inkl. Rabatte, exklusive Bearbeitungsgebühren) | | pay_fee | number(float) | false | none | Tatsächlich gezahlter Betrag (einschließlich Rabatte und Bearbeitungsgebühren) | | discount_fee | number(float) | false | none | Rabattbetrag | | handling_fee | number(float) | false | none | Bearbeitungsgebühr | | refund_fee | number(float) | false | none | Rückerstattungsbetrag | | pm_id | integer | false | none | Zahlungsmethoden-ID (aus /open/zahlung/list) | | pm_title | string | false | none | Name der Zahlungsmethode | | pm_logo | string | false | none | Zahlungsmethode-Logo-URL | | status | integer | false | none | Bestellstatus
| Wert | Beschreibung |
| --- | --- |
| 0 | Ausstehende Zahlung |
| 1 | Bezahlt |
| 2 | Timeout-Stornierung |
| 3 | Erstattet | | | title | string | false | none | Pakettitel | | detail | string | false | none | Paketbeschreibung | | region_desc | string | false | none | Beschreibung der Regionsspezifikation | | pay_at | string(date-time) | false | none | Zahlungszeitpunkt | | pay_timestamp | integer | false | none | Zahlungszeitstempel | | created_at | string(date-time) | false | none | Schöpfungszeit | | pay_fee_status | integer | false | none | Status der langen und kurzen Zahlung: 0 normal 1 lange Zahlung (Überzahlung) 2 kurze Zahlung | | invoice | object | false | none | Rechnungsinformationen (nur wertvoll für Online-Zahlungsaufträge) | | » name | string | false | none | vollständiger Name | | » org_name | string | false | none | Name der Firma | | » first_name | string | false | none | none | | » last_name | string | false | none | none | | » phone | string | false | none | none | | » email | string(email) | false | none | none | | » role_type | integer | false | none | 1 Person 2 Unternehmen | | » vat_id | string | false | none | Steuer-ID-Nummer | | » address_country | string | false | none | none | | » address_city | string | false | none | none | | » address_line1 | string | false | none | none | | » address_line2 | string | false | none | none | | » address_postal_code | string | false | none | none |
OrderCheckResult
{
"product_id": 0,
"amount": 0,
"discount_fee": 0.1,
"total_fee": 0.1,
"pay_fee": 0.1,
"product_type": 0,
"title": "string",
"detail": "string",
"ip_result": [
{
"ip": "string",
"price": 0.1,
"country_code": "string",
"current_time": "2019-08-24T14:15:22Z",
"renewal_time": "2019-08-24T14:15:22Z",
"country": {
"name_zh_cn": "string",
"flag": "string",
"square_flag": "string"
}
}
]
}
Bestellen Sie die Ergebnisse der Vorkontrolle
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| product_id | integer | false | none | Paket-ID |
| amount | integer | false | none | Menge |
| discount_fee | number(float) | false | none | Rabattbetrag |
| total_fee | number(float) | false | none | Bestellsumme |
| pay_fee | number(float) | false | none | Tatsächlich gezahlter Betrag |
| product_type | integer | false | none | Pakettyp |
| title | string | false | none | Pakettitel |
| detail | string | false | none | Paketbeschreibung |
| ip_result | [object] | false | none | Ergebnisse der IP-Batch-Erneuerung (wird nur während der IP-Erneuerung zurückgegeben) |
| » ip | string | false | none | none |
| » price | number(float) | false | none | none |
| » country_code | string | false | none | none |
| » current_time | string(date-time) | false | none | none |
| » renewal_time | string(date-time) | false | none | none |
| » country | object | false | none | none |
| »» name_zh_cn | string | false | none | none |
| »» flag | string | false | none | Kreis-Flag-URL |
| »» square_flag | string | false | none | Square-Flag-URL |
Product
{
"id": 0,
"title": "string",
"type": 0,
"show_type": 0,
"status": 0,
"price": 0.1,
"usd_price": 0.1,
"price_hkd": 0.1,
"original_price": 0.1,
"original_usd_price": 0.1,
"original_price_hkd": 0.1,
"local_price": 0.1,
"local_original_price": 0.1,
"preferred_currency": "string",
"support_currencies": "string",
"flow_value": 0.1,
"flow_give": 0.1,
"balance_give": 0.1,
"balance_value": 0.1,
"time_validity": 0.1,
"time_price": 0.1,
"time_days": 0,
"tip1": "string",
"tip2": "string",
"introduce": ["string"],
"region_list_id": 0,
"renew_product_list": "string",
"parent_product_type": 0,
"total_count": 0,
"remain_count": 0,
"extension_of_time_days": [0],
"time_days_price_rate": 0.1,
"desc": {
"subtitle": "string",
"flow_value": 0.1,
"flow_give": 0.1,
"balance_give": 0.1,
"time_validity": 0.1,
"time_price": 0.1,
"tip1": "string",
"tip2": "string",
"introduce": ["string"]
},
"sku": {
"bandwidth_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
],
"duration_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
],
"concurrency_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
]
}
}
Properties
| Name | Type | Required | Restrictions | Description | | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | | id | integer | false | none | Paket-ID | | title | string | false | none | Haupttitel des Pakets | | type | integer | false | none | Pakettyp
| Wert | Beschreibung |
| --- | --- |
| 3 | Guthaben aufladen |
| 9 | Dynamisches Anliegerverkehrspaket |
| 10 | Dynamisches globales Paketpaket |
| 11 | Angepasstes dynamisches globales Paket V2 (einschließlich SKU) |
| 12 | Langfristiges IDC-Verkehrspaket |
| 13 | Statisches IP-Verkehrspaket für Privathaushalte |
| 14 | Statisches IP-Paket für Rechenzentrum |
| 15 | Langfristiges ISP-Traffic-Paket |
| 16 | Statisches Verkehrspaket |
| 17 | Dynamisches IP-Paket für Privathaushalte |
| 19 | Statisches IP-Erneuerungspaket |
| 20 | Statische IP-Ersatzqualifikationen |
| 21 | Statisches IP-Paket für Privathaushalte |
| 24 | Add-on-Paket für statischen Datenverkehr |
| 25 | Statisches IP-Tarifpaket | | | show_type | integer | false | none | Anzeigetyp: 1 Normal 2 Große Empfehlung 3 Nicht zum Kauf verfügbar (Anpassung erforderlich) 4 Testversion | | status | integer | false | none | Status: 1 im Regal, 0 im Regal | | price | number(float) | false | none | RMB-Preis | | usd_price | number(float) | false | none | Dollarpreis | | price_hkd | number(float) | false | none | Hongkong-Dollar-Preis | | original_price | number(float) | false | none | Originalpreis (CNY) | | original_usd_price | number(float) | false | none | Originalpreis (USD) | | original_price_hkd | number(float) | false | none | Originalpreis (HKD) | | local_price | number(float) | false | none | Lokalisierter Preis (abhängig von der bevorzugten_Währung) | | local_original_price | number(float) | false | none | Lokalisierter Originalpreis (abhängig von der bevorzugten_Währung) | | preferred_currency | string | false | none | Es wird empfohlen, die Währung anzuzeigen, z. B. USD / CNY / HKD | | support_currencies | string | false | none | Liste der unterstützten Währungen, durch Kommas getrennt, z. B. USD, CNY | | flow_value | number(float) | false | none | Standarddatenverkehr des Datentarifs (GB) | | flow_give | number(float) | false | none | Kostenloser Traffic (GB) | | balance_give | number(float) | false | none | Bonus zum Aufladen des Guthabens | | balance_value | number(float) | false | none | Aufladebetrag | | time_validity | number(float) | false | none | Der Standardgültigkeitszeitraum von Standardplänen | | time_price | number(float) | false | none | Standardpaketpreis pro IP | | time_days | integer | false | none | Anzahl der Gültigkeitstage, z. B. 30/90/180/365 | | tip1 | string | false | none | Etikettenbeschreibung 1 | | tip2 | string | false | none | Etikettenbeschreibung 2 | | introduce | [string] | false | none | Texteinführungsliste | | region_list_id | integer | false | none | Regions-ID | | renew_product_list | string | false | none | Liste der erneuerbaren Paket-IDs (durch Kommas getrennt) | | parent_product_type | integer | false | none | Typ des übergeordneten Pakets (gültig, wenn Typ=19): 14 oder 25 | | total_count | integer | false | none | Gesamtbestand, 0 bedeutet keine Begrenzung | | remain_count | integer | false | none | Restposten | | extension_of_time_days | [integer] | false | none | Liste der Dauermultiplikatoren. Wenn es leer ist oder nur 1 enthält, bedeutet dies, dass es nicht unterstützt wird. | | time_days_price_rate | number(float) | false | none | Dauerpreiskoeffizient, Preis × (1 + (multiplizieren-1) × Tarif) | | desc | object | false | none | Informationen zur Paketbeschreibung | | » subtitle | string | false | none | Untertitel | | » flow_value | number(float) | false | none | none | | » flow_give | number(float) | false | none | none | | » balance_give | number(float) | false | none | none | | » time_validity | number(float) | false | none | none | | » time_price | number(float) | false | none | none | | » tip1 | string | false | none | none | | » tip2 | string | false | none | none | | » introduce | [string] | false | none | none | | sku | object | false | none | Spezifikationsparameter (zurückgegeben, wenn Typ=11) | | » bandwidth_list | [object] | false | none | Liste der Bandbreitenspezifikationen | | »» id | integer | false | none | none | | »» value | integer | false | none | Bandbreitenwert (Mbps) | | »» price | number(float) | false | none | none | | »» price_usd | number(float) | false | none | none | | »» price_hkd | number(float) | false | none | none | | » duration_list | [object] | false | none | Liste der Dauerspezifikationen | | »» id | integer | false | none | none | | »» value | integer | false | none | Dauer (Tage) | | »» price | number(float) | false | none | none | | »» price_usd | number(float) | false | none | none | | »» price_hkd | number(float) | false | none | none | | » concurrency_list | [object] | false | none | Liste der Parallelitätsspezifikationen | | »» id | integer | false | none | none | | »» value | integer | false | none | Anzahl der Parallelitäten | | »» price | number(float) | false | none | none | | »» price_usd | number(float) | false | none | none | | »» price_hkd | number(float) | false | none | none |
WhiteIp
{
"id": 0,
"ip": "string",
"remark": "string",
"created_at": "2019-08-24T14:15:22Z"
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| ip | string | false | none | none |
| remark | string | false | none | none |
| created_at | string(date-time) | false | none | none |
WhitelistAccount
{
"id": 0,
"username": "string",
"limit": 0,
"used": 0,
"status": 0
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| username | string | false | none | none |
| limit | integer | false | none | none |
| used | integer | false | none | none |
| status | integer | false | none | none |
Coupon
{
"id": 0,
"name": "string",
"code": "string",
"discount": 0.1,
"expire_time": "2019-08-24T14:15:22Z"
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| name | string | false | none | none |
| code | string | false | none | none |
| discount | number(float) | false | none | none |
| expire_time | string(date-time) | false | none | none |
Article
{
"id": 0,
"title": "string",
"content": "string",
"created_at": "2019-08-24T14:15:22Z"
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| title | string | false | none | none |
| content | string | false | none | none |
| created_at | string(date-time) | false | none | none |
Pagination
{
"total": 0,
"page_no": 0,
"page_size": 0,
"total_pages": 0
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| total | integer | false | none | none |
| page_no | integer | false | none | none |
| page_size | integer | false | none | none |
| total_pages | integer | false | none | none |